Crate fack_codegen

Crate fack_codegen 

Code generation for the fack crate.

This is not a proc-macro crate, therefore, this can be freely depended upon in both normal and procedural macro contexts.

Modules

common
Shared error characteristics for the error type generation process.
enumerate
The enumeration error type.
expand
Final code expansion for error definitions.
structure
The structure error type.

Enums

Target
An error-derivation target.